==> BittenBaum-3.00.tar.bz2: BittenBaum-3.00/gui/BittenBaum/Smdn.Applications.BittenBaum.UI/MainWindow.Controls.cs <==
//  
//  Author:
//       smdn <smdn@smdn.jp>
// 
//  Copyright (c) 2003-2013 smdn
// 
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
// 
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
//  GNU General Public License for more details.
//  
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

using System;
using System.Drawing;
using System.Windows.Forms;

using Smdn.IO.FileSystems;

namespace Smdn.Applications.BittenBaum.UI {
  using Graphing;

  public partial class MainWindow {
    private interface IDirectoryContainer {
      Directory Directory { get; }
    }

    private class DirectoryToolStripButton : ToolStripButton, IDirectoryContainer {
      public Directory Directory {
        get; private set;
      }

      public DirectoryToolStripButton(Environment.SpecialFolder specialFolder, EventHandler onClick)
        : base(GetText(specialFolder), GetIcon(specialFolder), onClick)
      {
        this.Directory = GetDirectory(specialFolder);

        this.ToolTipText = this.Text;
        this.DisplayStyle = ToolStripItemDisplayStyle.Image;
      }

      internal static string GetText(Environment.SpecialFolder specialFolder)
      {
        switch (specialFolder) {
          case Environment.SpecialFolder.Desktop: return "デスクトップ";
          case Environment.SpecialFolder.MyDocuments: return Runtime.IsRunningOnWindows ? "マイ ドキュメント" : "ホーム";
          case Environment.SpecialFolder.ProgramFiles: return "プログラム ファイル";
          default: return specialFolder.ToString();
        }
      }

      internal static Bitmap GetIcon(Environment.SpecialFolder specialFolder)
      {
        switch (specialFolder) {
          case Environment.SpecialFolder.Desktop: return IconTheme.GetIcon(IconType.DesktopFolder);
          case Environment.SpecialFolder.MyDocuments: return IconTheme.GetIcon(IconType.MyDocumentFolder);
          case Environment.SpecialFolder.ProgramFiles: return IconTheme.GetIcon(IconType.ProgramFilesFolder);
          default: return IconTheme.GetIcon(GetDirectory(specialFolder));
        }
      }

      internal static Directory GetDirectory(Environment.SpecialFolder specialFolder)
      {
        return FileSystem.GetDirectory(Environment.GetFolderPath(specialFolder));
      }
    }

    private class DirectoryToolStripMenuItem : ToolStripMenuItem, IDirectoryContainer {
      public Directory Directory {
        get; private set;
      }

      public DirectoryToolStripMenuItem(Environment.SpecialFolder specialFolder, EventHandler onClick)
        : base(DirectoryToolStripButton.GetText(specialFolder), DirectoryToolStripButton.GetIcon(specialFolder), onClick)
      {
        this.Directory = DirectoryToolStripButton.GetDirectory(specialFolder);
      }
    }

    private interface IDriveContainer {
      Drive Drive { get; }
    }

    private class DriveToolStripButton : ToolStripButton, IDriveContainer {
      public Drive Drive {
        get; private set;
      }

      public DriveToolStripButton(Drive drive, EventHandler onClick)
        : base(GetText(drive), IconTheme.GetIcon(drive), onClick)
      {
        this.Drive = drive;

        this.ToolTipText = this.Text;
        this.DisplayStyle = ToolStripItemDisplayStyle.Image;
      }

      private static string GetText(Drive drive)
      {
        return string.Format("{0}{1}{2}, {3}", drive.RootDirectory.FullName, Environment.NewLine, drive.Name, drive.Format);
      }
    }

    private class DriveToolStripMenuItem : ToolStripMenuItem, IDriveContainer {
      public Drive Drive {
        get; private set;
      }

      public DriveToolStripMenuItem(Drive drive, EventHandler onClick)
        : base(GetText(drive), IconTheme.GetIcon(drive), onClick)
      {
        this.Drive = drive;
      }

      private static string GetText(Drive drive)
      {
        var text = drive.RootDirectory.FullName;

        if (Runtime.IsRunningOnWindows) {
          // ニーモニック(X:\...の形式になるので、1文字目をニーモニック文字とする)
          if (Char.IsLetter(text, 0))
            text = "&" + text;
        }
        else {
          // ニーモニック(/xxx/...の形式になるので、2文字目をニーモニック文字とする)
          if (2 <= text.Length && Char.IsLetter(text, 1))
            text = text.Substring(0, 1) + "&" + text.Substring(1);
        }

        return string.Format("{0} ({1}, {2})", text, drive.Name, drive.Format);
      }
    }

    private interface IVisualizerControl {
      Visualizer Visualizer { get; }
    }

    private class VisualizedHistoryToolStripButton : ToolStripButton, IVisualizerControl {
      Visualizer IVisualizerControl.Visualizer {
        get { return visualizer; }
      }

      private readonly Visualizer visualizer;

      public VisualizedHistoryToolStripButton(Visualizer visualizer)
        : base()
      {
        this.visualizer = visualizer;
      }
    }

    private class VisualizedHistoryToolStripMenuItem : ToolStripMenuItem, IVisualizerControl {
      Visualizer IVisualizerControl.Visualizer {
        get { return visualizer; }
      }

      private readonly Visualizer visualizer;

      public VisualizedHistoryToolStripMenuItem(Visualizer visualizer)
        : base()
      {
        this.visualizer = visualizer;
      }
    }

    private interface IDirectoryEntryContextMenuStrip {
      DirectoryEntry DirectoryEntry { get; }
    }

    private class GraphElementContextMenuStrip : ContextMenuStrip, IDirectoryEntryContextMenuStrip {
      public IGraphElement Element {
        get { return element; }
      }

      DirectoryEntry IDirectoryEntryContextMenuStrip.DirectoryEntry {
        get { return element.Entry; }
      }

      private IGraphElement element = null;

      public void Show(Control control, int x, int y, IGraphElement element)
      {
        this.element = element;

        base.Show(control, x, y);
      }
    }

    private class DirectoryTreeContextMenuStrip : ContextMenuStrip, IDirectoryEntryContextMenuStrip {
      public DirectoryTree DirectoryTree {
        get { return directoryTree; }
      }

      DirectoryEntry IDirectoryEntryContextMenuStrip.DirectoryEntry {
        get { return directoryTree; }
      }

      private DirectoryTree directoryTree = null;

      public void Show(Control control, int x, int y, DirectoryTree directoryTree)
      {
        this.directoryTree = directoryTree;

        base.Show(control, x, y);
      }
    }

    private class DirectoryEntryToolStripMenuItem : ToolStripMenuItem {
      public string FormatString {
        get; private set;
      }

      public DirectoryEntryToolStripMenuItem(string formatString, EventHandler onClick)
      {
        this.FormatString = formatString;
        this.Click += onClick;
      }

      public void UpdateText(DirectoryEntry entry)
      {
        var entryName = entry.Name;
        var parentName = entry.Parent.Name;
        const int lengthLimit = 24;

        if (lengthLimit < entryName.Length)
          entryName = entryName.Substring(0, lengthLimit) + "...";

        if (lengthLimit < parentName.Length)
          parentName = parentName.Substring(0, lengthLimit) + "...";

        Text = string.Format(FormatString, entryName, parentName);
      }
    }

    private class TabulatorToolStripMenuItem : ToolStripMenuItem {
      public TabulatorToolStripMenuItem(string text, EventHandler onClick)
      {
        this.Text = text;
        this.Click += onClick;
      }
    }

    private class SearchQueryRegexToolStripMenuItem : ToolStripMenuItem {
      public string Pattern {
        get; private set;
      }

      public SearchQueryRegexToolStripMenuItem(string text, string pattern)
      {
        this.Text = text;
        this.Pattern = pattern;
      }
    }
  }
}

==> BittenBaum-3.01.tar.bz2: BittenBaum-3.01/gui/BittenBaum/Smdn.Applications.BittenBaum.UI/MainWindow.Controls.cs <==
//  
//  Author:
//       smdn <smdn@smdn.jp>
// 
//  Copyright (c) 2003-2013 smdn
// 
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
// 
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
//  GNU General Public License for more details.
//  
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

using System;
using System.Drawing;
using System.Windows.Forms;

using Smdn.IO.FileSystems;

namespace Smdn.Applications.BittenBaum.UI {
  using Graphing;

  public partial class MainWindow {
    private interface IDirectoryContainer {
      Directory Directory { get; }
    }

    private class DirectoryToolStripButton : ToolStripButton, IDirectoryContainer {
      public Directory Directory {
        get; private set;
      }

      public DirectoryToolStripButton(Environment.SpecialFolder specialFolder, EventHandler onClick)
        : base(GetText(specialFolder), GetIcon(specialFolder), onClick)
      {
        this.Directory = GetDirectory(specialFolder);

        this.ToolTipText = this.Text;
        this.DisplayStyle = ToolStripItemDisplayStyle.Image;
      }

      internal static string GetText(Environment.SpecialFolder specialFolder)
      {
        switch (specialFolder) {
          case Environment.SpecialFolder.Desktop: return "デスクトップ";
          case Environment.SpecialFolder.MyDocuments: return Runtime.IsRunningOnWindows ? "マイ ドキュメント" : "ホーム";
          case Environment.SpecialFolder.ProgramFiles: return "プログラム ファイル";
          default: return specialFolder.ToString();
        }
      }

      internal static Bitmap GetIcon(Environment.SpecialFolder specialFolder)
      {
        switch (specialFolder) {
          case Environment.SpecialFolder.Desktop: return IconTheme.GetIcon(IconType.DesktopFolder);
          case Environment.SpecialFolder.MyDocuments: return IconTheme.GetIcon(IconType.MyDocumentFolder);
          case Environment.SpecialFolder.ProgramFiles: return IconTheme.GetIcon(IconType.ProgramFilesFolder);
          default: return IconTheme.GetIcon(GetDirectory(specialFolder));
        }
      }

      internal static Directory GetDirectory(Environment.SpecialFolder specialFolder)
      {
        return FileSystem.GetDirectory(Environment.GetFolderPath(specialFolder));
      }
    }

    private class DirectoryToolStripMenuItem : ToolStripMenuItem, IDirectoryContainer {
      public Directory Directory {
        get; private set;
      }

      public DirectoryToolStripMenuItem(Environment.SpecialFolder specialFolder, EventHandler onClick)
        : base(DirectoryToolStripButton.GetText(specialFolder), DirectoryToolStripButton.GetIcon(specialFolder), onClick)
      {
        this.Directory = DirectoryToolStripButton.GetDirectory(specialFolder);
      }
    }

    private interface IDriveContainer {
      Drive Drive { get; }
    }

    private class DriveToolStripButton : ToolStripButton, IDriveContainer {
      public Drive Drive {
        get; private set;
      }

      public DriveToolStripButton(Drive drive, EventHandler onClick)
        : base(GetText(drive), IconTheme.GetIcon(drive), onClick)
      {
        this.Drive = drive;

        this.ToolTipText = this.Text;
        this.DisplayStyle = ToolStripItemDisplayStyle.Image;
      }

      private static string GetText(Drive drive)
      {
        return string.Format("{0}{1}{2}, {3}", drive.RootDirectory.FullName, Environment.NewLine, drive.Name, drive.Format);
      }
    }

    private class DriveToolStripMenuItem : ToolStripMenuItem, IDriveContainer {
      public Drive Drive {
        get; private set;
      }

      public DriveToolStripMenuItem(Drive drive, EventHandler onClick)
        : base(GetText(drive), IconTheme.GetIcon(drive), onClick)
      {
        this.Drive = drive;
      }

      private static string GetText(Drive drive)
      {
        var text = drive.RootDirectory.FullName;

        if (Runtime.IsRunningOnWindows) {
          // ニーモニック(X:\...の形式になるので、1文字目をニーモニック文字とする)
          if (Char.IsLetter(text, 0))
            text = "&" + text;
        }
        else {
          // ニーモニック(/xxx/...の形式になるので、2文字目をニーモニック文字とする)
          if (2 <= text.Length && Char.IsLetter(text, 1))
            text = text.Substring(0, 1) + "&" + text.Substring(1);
        }

        return string.Format("{0} ({1}, {2})", text, drive.Name, drive.Format);
      }
    }

    private interface IVisualizerControl {
      Visualizer Visualizer { get; }
    }

    private class VisualizedHistoryToolStripButton : ToolStripButton, IVisualizerControl {
      Visualizer IVisualizerControl.Visualizer {
        get { return visualizer; }
      }

      private readonly Visualizer visualizer;

      public VisualizedHistoryToolStripButton(Visualizer visualizer)
        : base()
      {
        this.visualizer = visualizer;
      }
    }

    private class VisualizedHistoryToolStripMenuItem : ToolStripMenuItem, IVisualizerControl {
      Visualizer IVisualizerControl.Visualizer {
        get { return visualizer; }
      }

      private readonly Visualizer visualizer;

      public VisualizedHistoryToolStripMenuItem(Visualizer visualizer)
        : base()
      {
        this.visualizer = visualizer;
      }
    }

    private interface IDirectoryEntryContextMenuStrip {
      DirectoryEntry DirectoryEntry { get; }
    }

    private class GraphElementContextMenuStrip : ContextMenuStrip, IDirectoryEntryContextMenuStrip {
      public IGraphElement Element {
        get { return element; }
      }

      DirectoryEntry IDirectoryEntryContextMenuStrip.DirectoryEntry {
        get { return element.Entry; }
      }

      private IGraphElement element = null;

      public void Show(Control control, int x, int y, IGraphElement element)
      {
        this.element = element;

        base.Show(control, x, y);
      }
    }

    private class DirectoryTreeContextMenuStrip : ContextMenuStrip, IDirectoryEntryContextMenuStrip {
      public DirectoryTree DirectoryTree {
        get { return directoryTree; }
      }

      DirectoryEntry IDirectoryEntryContextMenuStrip.DirectoryEntry {
        get { return directoryTree; }
      }

      private DirectoryTree directoryTree = null;

      public void Show(Control control, int x, int y, DirectoryTree directoryTree)
      {
        this.directoryTree = directoryTree;

        base.Show(control, x, y);
      }
    }

    private class DirectoryEntryToolStripMenuItem : ToolStripMenuItem {
      public string FormatString {
        get; private set;
      }

      public DirectoryEntryToolStripMenuItem(string formatString, EventHandler onClick)
      {
        this.FormatString = formatString;
        this.Click += onClick;
      }

      public void UpdateText(DirectoryEntry entry)
      {
        var entryName = entry.Name;
        var parentName = (entry.Parent == null) ? string.Empty : entry.Parent.Name;
        const int lengthLimit = 24;

        if (lengthLimit < entryName.Length)
          entryName = entryName.Substring(0, lengthLimit) + "...";

        if (lengthLimit < parentName.Length)
          parentName = parentName.Substring(0, lengthLimit) + "...";

        Text = string.Format(FormatString, entryName, parentName);
      }
    }

    private class ParentDirectoryEntryToolStripMenuItem : DirectoryEntryToolStripMenuItem {
      public ParentDirectoryEntryToolStripMenuItem(string formatString, EventHandler onClick)
        : base(formatString, onClick)
      {
      }
    }

    private class TabulatorToolStripMenuItem : ToolStripMenuItem {
      public TabulatorToolStripMenuItem(string text, EventHandler onClick)
      {
        this.Text = text;
        this.Click += onClick;
      }
    }

    private class SearchQueryRegexToolStripMenuItem : ToolStripMenuItem {
      public string Pattern {
        get; private set;
      }

      public SearchQueryRegexToolStripMenuItem(string text, string pattern)
      {
        this.Text = text;
        this.Pattern = pattern;
      }
    }
  }
}
